==> cv-dialog-sdk-4.0.0.tgz: package/src/js/catavolt/storage/Storage.js <==
var ApiType;
(function (ApiType) {
    ApiType[ApiType["LOCAL_STORAGE"] = 0] = "LOCAL_STORAGE";
    ApiType[ApiType["ASYNC_STORAGE"] = 1] = "ASYNC_STORAGE";
})(ApiType || (ApiType = {}));
export class Storage {
    static setStorageApi(storageApi) {
        Storage._storageApi = storageApi;
    }
    constructor() {
        this.initStorageApi();
    }
    getItem(key) {
        if (this._type === ApiType.ASYNC_STORAGE) {
            return this.getItemAsyncStorage(key, Storage._storageApi);
        }
        else if (this._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    setItem(key, value) {
        if (this._type === ApiType.ASYNC_STORAGE) {
            return this.setItemAsyncStorage(key, value, Storage._storageApi);
        }
        else if (this._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    removeItem(key) {
        if (this._type === ApiType.ASYNC_STORAGE) {
            return this.removeItemAsyncStorage(key, Storage._storageApi);
        }
        else if (this._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    clearAll() {
        if (this._type === ApiType.ASYNC_STORAGE) {
            return this.clearAllAsyncStorage(Storage._storageApi);
        }
        else if (this._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    getAllKeys() {
        if (this._type === ApiType.ASYNC_STORAGE) {
            return this.getAllKeysAsyncStorage(Storage._storageApi);
        }
        else if (this._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    multiRemove(keys) {
        if (this._type === ApiType.ASYNC_STORAGE) {
            return this.multiRemoveAsyncStorage(keys, Storage._storageApi);
        }
        else if (this._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    initStorageApi() {
        if (Storage._storageApi) {
            if (Storage._storageApi.getAllKeys) {
                // Assume AsyncStorage
                this._type = ApiType.ASYNC_STORAGE;
            }
            else {
                // Assume window.localStorage
                this._type = ApiType.LOCAL_STORAGE;
            }
        }
        else {
            // Try for window.localStorage
            if (window.localStorage) {
                this._type = ApiType.LOCAL_STORAGE;
            }
            else {
                throw new Error("No Storage Api specified for Storage");
            }
        }
    }
    getItemAsyncStorage(key, api) {
        return api.getItem(key).then((value) => {
            try {
                return JSON.parse(value);
            }
            catch (err) {
                throw new Error(`Storage::getItem('${key}') parse JSON failed for: ${value}`);
            }
        });
    }
    setItemAsyncStorage(key, value, api) {
        let stringVal = null;
        try {
            stringVal = JSON.stringify(value);
        }
        catch (err) {
            return Promise.reject(new Error(`Storage::setItem(${key}) failed to stringify JSON value`));
        }
        return api.setItem(key, stringVal);
    }
    removeItemAsyncStorage(key, api) {
        return api.removeItem(key);
    }
    clearAllAsyncStorage(api) {
        return api.clear();
    }
    getAllKeysAsyncStorage(api) {
        return api.getAllKeys();
    }
    multiRemoveAsyncStorage(keys, api) {
        return api.multiRemove(keys);
    }
}

==> cv-dialog-sdk-4.1.0.tgz: package/src/js/catavolt/storage/Storage.js <==
var ApiType;
(function (ApiType) {
    ApiType[ApiType["LOCAL_STORAGE"] = 0] = "LOCAL_STORAGE";
    ApiType[ApiType["ASYNC_STORAGE"] = 1] = "ASYNC_STORAGE";
})(ApiType || (ApiType = {}));
export class Storage {
    static setStorageApi(storageApi) {
        Storage._storageApi = storageApi;
    }
    constructor() {
        this.initStorageApi();
    }
    getItem(key) {
        if (this._type === ApiType.ASYNC_STORAGE) {
            return this.getItemAsyncStorage(key, Storage._storageApi);
        }
        else if (this._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    setItem(key, value) {
        if (this._type === ApiType.ASYNC_STORAGE) {
            return this.setItemAsyncStorage(key, value, Storage._storageApi);
        }
        else if (this._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    removeItem(key) {
        if (this._type === ApiType.ASYNC_STORAGE) {
            return this.removeItemAsyncStorage(key, Storage._storageApi);
        }
        else if (this._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    clearAll() {
        if (this._type === ApiType.ASYNC_STORAGE) {
            return this.clearAllAsyncStorage(Storage._storageApi);
        }
        else if (this._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    getAllKeys() {
        if (this._type === ApiType.ASYNC_STORAGE) {
            return this.getAllKeysAsyncStorage(Storage._storageApi);
        }
        else if (this._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    multiRemove(keys) {
        if (this._type === ApiType.ASYNC_STORAGE) {
            return this.multiRemoveAsyncStorage(keys, Storage._storageApi);
        }
        else if (this._type === ApiType.LOCAL_STORAGE) {
            // @TODO
        }
    }
    initStorageApi() {
        if (Storage._storageApi) {
            if (Storage._storageApi.getAllKeys) {
                // Assume AsyncStorage
                this._type = ApiType.ASYNC_STORAGE;
            }
            else {
                // Assume window.localStorage
                this._type = ApiType.LOCAL_STORAGE;
            }
        }
        else {
            // Try for window.localStorage
            if (window.localStorage) {
                this._type = ApiType.LOCAL_STORAGE;
            }
            else {
                throw new Error('No Storage Api specified for Storage');
            }
        }
    }
    getItemAsyncStorage(key, api) {
        return api.getItem(key).then(value => {
            try {
                return JSON.parse(value);
            }
            catch (err) {
                throw new Error(`Storage::getItem('${key}') parse JSON failed for: ${value}`);
            }
        });
    }
    setItemAsyncStorage(key, value, api) {
        let stringVal = null;
        try {
            stringVal = JSON.stringify(value);
        }
        catch (err) {
            return Promise.reject(new Error(`Storage::setItem(${key}) failed to stringify JSON value`));
        }
        return api.setItem(key, stringVal);
    }
    removeItemAsyncStorage(key, api) {
        return api.removeItem(key);
    }
    clearAllAsyncStorage(api) {
        return api.clear();
    }
    getAllKeysAsyncStorage(api) {
        return api.getAllKeys();
    }
    multiRemoveAsyncStorage(keys, api) {
        return api.multiRemove(keys);
    }
}
